@@ -1,13 +1,12 @@
 use super::list::ListFormat;
 use std::{rc::Rc, sync::Arc};
-use swc_common::{
-    errors::SourceMapper, BytePos, SourceMap, SourceMapperDyn, Span, Spanned, SyntaxContext,
-};
+use swc_common::{errors::SourceMapper, BytePos, SourceMap, SourceMapperDyn, Span, Spanned};
 use swc_ecma_ast::*;
 
 pub trait SpanExt: Spanned {
+    #[inline]
     fn is_synthesized(&self) -> bool {
-        self.span().ctxt() != SyntaxContext::empty()
+        false
     }
 
     fn starts_on_new_line(&self, format: ListFormat) -> bool {
